@@ -8,7 +8,7 @@ import (
 	. "github.com/docker/cli/internal/test/builders" // Import builders to get the builder function as package functions
 	"github.com/docker/docker/api/types/swarm"
 	"github.com/pkg/errors"
-	"gotest.tools/assert"
+	"gotest.tools/v3/assert"
 )
 
 func TestNodeDemoteErrors(t *testing.T) {
